What’s New in Bazaar 2.7? — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# What’s New in Bazaar 2.7?

Bazaar 2.7 has been released on the 1st of February 2016 and marks the start of a new long-term stable series. From here, we will only make bugfix releases on the 2.7 series (2.7.1, etc), while 2.8 will become our new development series.

This document accumulates a high level summary of what’s changed. See the Breezy Release Notes for a full list.

Users are encouraged to upgrade from the other stable series. This document outlines the improvements in Bazaar 2.7 vs Bazaar 2.6. As well as summarizing improvements made to the core product, it highlights enhancements within the broader Bazaar world of potential interest to those upgrading.

Bazaar 2.7.0 is fully compatible both locally and on the network with 2.0, 2.1, 2.2, 2.3, 2.4, 2.5 and 2.6, and can read and write repositories generated by all previous versions.

## python-2.6 EOL’ed

python 2.6 has been EOL’ed since the release of bzr 2.6. The last python 2.6 version was released on 2013-10-29. While bzr 2.7 remains compatible with python 2.6, no further update of bzr is expected in this regard.

## SSL Certificate Verification Support in urllib HTTPS backend

python 2.7 received security updates regarding SSL certificate verification. bzr 2.7 relies on the ssl python module for this and as such benefit from these security updates.

This isn’t true for python 2.6 so users are encouraged to upgrade.

Users that cannot upgrade will be warned that the hostname cannot be verified and can remove the warnings by setting the `ssl.cert_reqs` option to `none`.

## Test reliability

Most of the bug fixes in 2.7 are related to test failures triggered by various python 2.7 updates. Among other distributions, debian and ubuntu have carried patches that have now part of bzr 2.7.

## Further information

For more detailed information on the changes made, see the the Breezy Release Notes for:

- the interim bzr milestones

- the plugins you use.

For a summary of changes made in earlier releases, see:

- What’s New in Bazaar 2.1?

- What’s New in Bazaar 2.2?

- What’s New in Bazaar 2.3?

- What’s New in Bazaar 2.4 (Oronsay)

- What’s New in Bazaar 2.5?

- What’s New in Bazaar 2.6?